<?xml version="1.0" encoding="UTF-8" standalone="yes"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" version="4.01" encoding="UTF-8"
						doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN"
						doctype-system="http://www.w3.org/TR/html4/loose.dtd"/>
<xsl:strip-space elements="*"/>

<!--
 出現頻度が高いのでパフォーマンス向上のため前へ
-->

<!-- 1件分の情報 -->
<xsl:template match="CONTENTS_AND_VARIATION">
<xsl:param name="isOutputDetail"/>
	<li>
		<span class="from">from : </span>
		<a href="{URL}"><xsl:value-of select="URL"/></a>
	</li>
</xsl:template>

<xsl:template match="RIDUAL_VERSION">
	<span class="version">
		Ver.<xsl:value-of select="MAJORVER"/>
		.<xsl:value-of select="MINORVER"/>
		.<xsl:value-of select="RELEACEVER"/><xsl:text> </xsl:text>
		<xsl:value-of select="SPECIALBUILD"/>
		BLD<xsl:value-of select="BUILDNO"/><xsl:text> </xsl:text>
		<xsl:value-of select="RESOURCEVER"/>
	</span>
</xsl:template>

<!-- object+embed -->
<xsl:template match="OBJECT_EMBED">
<xsl:param name="isOutputDetail"/>
	<li>object + embed
		<div class="boxscrl">
			<ol>
				<xsl:apply-templates select="CONTENTS_AND_VARIATION">
					<xsl:with-param name="isOutputDetail"
												select="$isOutputDetail"/>
				</xsl:apply-templates>
			</ol>
		</div>
	</li>
</xsl:template>

<!-- object only -->
<xsl:template match="OBJECT_ONLY">
<xsl:param name="isOutputDetail"/>
	<li><span class="unex">object only ( should be object+embed )</span>
		<div class="boxscrl">
			<ol>
				<xsl:apply-templates select="CONTENTS_AND_VARIATION">
					<xsl:with-param name="isOutputDetail"
												select="$isOutputDetail"/>
				</xsl:apply-templates>
			</ol>
		</div>
	</li>
</xsl:template>

<!-- embed only -->
<xsl:template match="EMBED_ONLY">
<xsl:param name="isOutputDetail"/>
	<li><span class="unex">embed only ( should be object+embed )</span>
		<div class="boxscrl">
			<ol>
				<xsl:apply-templates select="CONTENTS_AND_VARIATION">
					<xsl:with-param name="isOutputDetail"
												select="$isOutputDetail"/>
				</xsl:apply-templates>
			</ol>
		</div>
	</li>
</xsl:template>

<!-- embed+object -->
<xsl:template match="EMBED_OBJECT">
<xsl:param name="isOutputDetail"/>
	<li><span class="unex">embed + object ( should be object+embed )</span>
		<div class="boxscrl">
			<ol>
				<xsl:apply-templates select="CONTENTS_AND_VARIATION">
					<xsl:with-param name="isOutputDetail"
												select="$isOutputDetail"/>
				</xsl:apply-templates>
			</ol>
		</div>
	</li>
</xsl:template>


<!--
 本文はここから
-->
<xsl:template match="/">
	<html lang="ja">
	<head>
	<!-- meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/ -->
	<title>Ridual：Objects tag</title>
	<link href="mailto:ridual@nri.co.jp" rev="made"/>
	<link title="Ridual" href="css/import_style.css" rel="stylesheet"
									type="text/css" media="screen,print"/>
	<link href="css/print.css" rel="stylesheet" type="text/css" media="print"/>
	</head>

	<body id="objects">

	<!-- #layout -->
	<div id="layout">
		<xsl:apply-templates select="RidualReportObjectsTag"/>

		<hr/>

		<!-- #footer -->
		<div id="footer">
			<p>
				<img alt="Powered by Nomura Research Institute,Ltd."
					title="Powered by Nomura Research Institute,Ltd."
						height="15" width="300" src="img/logo_nri.gif"/>
			</p>
		</div>
		<!--/ #footer -->

	</div>
	<!--/ #layout -->
	
	</body>
	</html>
</xsl:template>

<xsl:template match="RidualReportObjectsTag">
	<!-- #header -->
	<div id="header">

		<!-- #logo -->	
		<div id="logo">
			<div class="ridual">
				<a target="_blank" href="http://www.ridual.jp">
					<img alt="Ridual logo" height="30" width="70"
														src="img/R_logo.gif"/>
				</a>
				<xsl:apply-templates select="RIDUAL_VERSION"/>
			</div>
		</div>
		<!-- /#logo -->	

		<!-- #line -->
		<div id="line">
			<!-- URL -->
			<p><xsl:apply-templates select="ANALYZE_SITE_CONFIG"/></p>
		</div>
		<!-- /#line -->
		
		<xsl:apply-templates select="ANALYZE_HISTORY"/>
	</div>
	<!-- #header -->

	<hr/>

	<!-- #path -->
	<div id="path">
	<h1>Objects</h1>
<!--
	<p class="xmlicon">
		<a href="xml/objects.tag.xml">XML</a>
	</p>
	<p class="csvicon">
		<a href="csv/objects.tag.csv">CSV</a>
	</p>
	<p class="countn">
		<span class="cdate">( checked on 2005/12/23 2:56:01 )</span>
	</p>
-->
	</div>
	<!-- /#path -->

	<!-- #content -->
	<div id="content">
	
	<!-- #switch -->
	<div id="switch">
		<p class="objcont">
			<a href="objects.html">[contents]</a> 
		</p>
		<p class="objdetail">
			<a href="objects.tag.detail.html">[tag/detail]</a>
		</p>
		<p class="description">Objects tag list</p>
		<br/>
	</div>
	<!-- /#switch -->

	<div class="box">
		<ol type="A">
			<xsl:variable name="sw" select="ANALYZE_HISTORY/IS_OUTPUT_DETAIL"/>
			<xsl:apply-templates select="OBJECT_EMBED">
				<xsl:with-param name="isOutputDetail" select="$sw"/>
			</xsl:apply-templates>
			<xsl:apply-templates select="OBJECT_ONLY">
				<xsl:with-param name="isOutputDetail" select="$sw"/>
			</xsl:apply-templates>
			<xsl:apply-templates select="EMBED_ONLY">
				<xsl:with-param name="isOutputDetail" select="$sw"/>
			</xsl:apply-templates>
			<xsl:apply-templates select="EMBED_OBJECT">
				<xsl:with-param name="isOutputDetail" select="$sw"/>
			</xsl:apply-templates>
		</ol>
	</div>
	
	</div>
	<!-- /#content -->
</xsl:template>

<xsl:template match="ANALYZE_SITE_CONFIG">
	<a target="_blank" href="{START_URIS}">
		<xsl:value-of select="START_URIS"/>
	</a>
</xsl:template>

<xsl:template match="ANALYZE_HISTORY">
	<!-- #menu -->
	<div id="menu">
		<ul>
			<li class="overview"><a href="index.html">Overview</a></li>
			<li class="sitemap"><a name="sitemap.html">Sitemap</a></li>
			<li class="pages"><a href="pages.html">Pages</a></li>
			<li class="resources"><a href="resources.html">Resources</a></li>
			<li class="outlink"><a href="outlink.html">OutLink</a></li>
			<li class="form"><a href="form.html">Form</a></li>
			<li class="script"><a href="script.html">Script</a></li>
			<li class="css"><a href="css.html">CSS</a></li>
			<li class="objects"><a href="objects.html">Objects</a></li>
			<li class="lost"><a href="lost.html">Lost</a></li>
			<li class="quality"><a href="quality.html">Quality</a></li>
			<li class="report"><a href="report.html">Report</a></li>
			<li class="datalist"><a name="data.html">Data</a></li>
		</ul>
	</div>
	<!-- /#menu -->
</xsl:template>

</xsl:stylesheet>
